==> kolourpaint_17.12.3.orig.tar.xz: kolourpaint-17.12.3/tools/flow/kpToolEraser.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_ERASER_H
#define KP_TOOL_ERASER_H


#include "kpToolFlowPixmapBase.h"


// Eraser = Brush but with foreground & background colors swapped (a few square brushes)
class kpToolEraser : public kpToolFlowPixmapBase
{
Q_OBJECT

public:
    kpToolEraser (kpToolEnvironment *environ, QObject *parent);

    void globalDraw () Q_DECL_OVERRIDE;


protected:
    QString haventBegunDrawUserMessage () const Q_DECL_OVERRIDE;

    bool haveSquareBrushes () const Q_DECL_OVERRIDE { return true; }
    bool colorsAreSwapped () const Q_DECL_OVERRIDE { return true; }
};


#endif  // KP_TOOL_ERASER_H

==> kolourpaint_21.12.3.orig.tar.xz: kolourpaint-21.12.3/tools/flow/kpToolEraser.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_ERASER_H
#define KP_TOOL_ERASER_H


#include "kpToolFlowPixmapBase.h"


// Eraser = Brush but with foreground & background colors swapped (a few square brushes)
class kpToolEraser : public kpToolFlowPixmapBase
{
Q_OBJECT

public:
    kpToolEraser (kpToolEnvironment *environ, QObject *parent);

    void globalDraw () override;


protected:
    QString haventBegunDrawUserMessage () const override;

    bool haveSquareBrushes () const override { return true; }
    bool colorsAreSwapped () const override { return true; }
};


#endif  // KP_TOOL_ERASER_H
